@@ -243,7 +243,7 @@ struct padthv1_env
 {
 	// envelope stages
 
-	enum Stage { Idle = 0, Attack, Decay, Sustain, Release };
+	enum Stage { Idle = 0, Attack, Decay, Sustain, Release, End };
 
 	// per voice
 
@@ -312,7 +312,7 @@ struct padthv1_env
 		}
 		else if (p->stage == Release) {
 			p->running = false;
-			p->stage = Idle;
+			p->stage = End;
 			p->frames = 0;
 			p->phase = 0.0f;
 			p->delta = 0.0f;
@@ -1051,7 +1051,7 @@ padthv1_impl::padthv1_impl (
 	padthv1 *pSampl, uint16_t nchannels, float srate )
 	: gen1_sample1(pSampl, 1), gen1_sample2(pSampl, 2),
 		m_controls(pSampl), m_programs(pSampl),
-		m_midi_in(pSampl), m_bpm(180.0f), m_running(false)
+		m_midi_in(pSampl), m_bpm(180.0f), m_nvoices(0), m_running(false)
 {
 	// null sample freqs.
 	m_gen1.sample1_0 = m_gen1.sample2_0 = 0.0f;
@@ -2157,7 +2157,7 @@ void padthv1_impl::process ( float **ins, float **outs, uint32_t nframes )
 			if (pv->dca1_env.running && pv->dca1_env.frames == 0)
 				m_dca1.env.next(&pv->dca1_env);
 
-			if (pv->dca1_env.stage == padthv1_env::Idle) {
+			if (pv->dca1_env.stage == padthv1_env::End) {
 				if (pv->note < 0)
 					free_voice(pv);
 				nblock = 0;
