@@ -1,7 +1,7 @@
 // padthv1widget_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -53,8 +53,8 @@ static const char *g_pszDefName = QT_TRANSLATE_NOOP("padthv1widget_config", "(de
 
 // ctor.
 padthv1widget_config::padthv1widget_config (
-	padthv1_ui *pSynthUi, QWidget *pParent, Qt::WindowFlags wflags )
-	: QDialog(pParent, wflags), p_ui(new Ui::padthv1widget_config), m_ui(*p_ui),
+	padthv1_ui *pSynthUi, QWidget *pParent )
+	: QDialog(pParent), p_ui(new Ui::padthv1widget_config), m_ui(*p_ui),
 		m_pSynthUi(pSynthUi)
 {
 	// Setup UI struct...
@@ -529,7 +529,7 @@ void padthv1widget_config::tuningScaleFileClicked (void)
 	const QString& sFilter = filters.join(";;");
 
 	QWidget *pParentWidget = nullptr;
-	QFileDialog::Options options = 0;
+	QFileDialog::Options options;
 	if (pConfig->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -578,7 +578,7 @@ void padthv1widget_config::tuningKeyMapFileClicked (void)
 	const QString& sFilter = filters.join(";;");
 
 	QWidget *pParentWidget = nullptr;
-	QFileDialog::Options options = 0;
+	QFileDialog::Options options;
 	if (pConfig->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -750,6 +750,14 @@ void padthv1widget_config::accept (void)
 			pConfig->sCustomStyleTheme.clear();
 		pConfig->fRandomizePercent = float(m_ui.RandomizePercentSpinBox->value());
 		int iNeedRestart = 0;
+		if (pConfig->sCustomStyleTheme != sOldCustomStyleTheme) {
+			if (pConfig->sCustomStyleTheme.isEmpty()) {
+				++iNeedRestart;
+			} else {
+				QApplication::setStyle(
+					QStyleFactory::create(pConfig->sCustomStyleTheme));
+			}
+ 		}
  		if (pConfig->sCustomColorTheme != sOldCustomColorTheme) {
 			if (pConfig->sCustomColorTheme.isEmpty()) {
 				++iNeedRestart;
@@ -760,14 +768,6 @@ void padthv1widget_config::accept (void)
 					QApplication::setPalette(pal);
 			}
  		}
-		if (pConfig->sCustomStyleTheme != sOldCustomStyleTheme) {
-			if (pConfig->sCustomStyleTheme.isEmpty()) {
-				++iNeedRestart;
-			} else {
-				QApplication::setStyle(
-					QStyleFactory::create(pConfig->sCustomStyleTheme));
-			}
- 		}
 		// Show restart message if needed...
  		if (iNeedRestart > 0) {
 			QMessageBox::information(this,
